/*  GTKtalog.
 *  Copyright (C) 1999  Mathieu VILLEGAS
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef TAGADA_TZOIN_TZOIN_POUET_POUET_H__
#define TAGADA_TZOIN_TZOIN_POUET_POUET_H__

#include <gtk/gtk.h>
#include "data.h"

typedef struct{
  unsigned char val;
  Folder *folder;
  char *data[7];//cotient toutes les infos de Folder en char
}search_info;

void open_result_dialog(GtkWidget *w);
void search_in_data(Folder *folder, gchar *filename,gchar *infostring, int in_file, int in_folder, int sensitive, gchar *cur_disk, gchar *cur_path);
void open_search_dialog(GtkWidget *w);
void list_folder(Folder *folder);
void affiche_files();
void affiche_row(search_info *info);



#endif
